@@ -1,8 +1,8 @@
 from abc import ABC, abstractmethod
 from copy import deepcopy
-from typing import Dict, List, Optional, Tuple
+from typing import Dict, List, Optional, Set, Tuple
 
-from hdx.scraper.utilities.reader import Read
+from .utilities.reader import Read
 
 
 class BaseScraper(ABC):
@@ -18,18 +18,23 @@ class BaseScraper(ABC):
 
     def __init__(
         self, name: str, datasetinfo: Dict, headers: Dict[str, Tuple]
-    ):
-        """
-        Create values member variable for inheriting scrapers to populate. It is of
-        form: {"national": ({"AFG": 1.2, "PSE": 1.4}, {"AFG": 123, "PSE": 241}, ...)}}
-        It should be called last from the inheriting scraper's constructor.
-        """
+    ) -> None:
         self.setup(name, headers)
         self.datasetinfo = deepcopy(datasetinfo)
         self.errors_on_exit = None
         self.can_fallback = True
 
-    def setup(self, name: str, headers: Dict[str, Tuple]):
+    def setup(self, name: str, headers: Dict[str, Tuple]) -> None:
+        """Initialise member variables including name and headers which is of form:
+        {"national": (("School Closure",), ("#impact+type",)), ...},
+
+        Args:
+            name (str): Name of scraper
+            headers: Dict[str, Tuple]: Headers to be oytput at each level_name
+
+        Returns:
+             None
+        """
         self.name = name
         self.headers = headers
         self.initialise_values_sources()
@@ -37,18 +42,17 @@ class BaseScraper(ABC):
         self.fallbacks_used = False
         self.source_urls = set()
 
-    def get_reader(
-        self, name: Optional[str] = None, prefix: Optional[str] = None
-    ):
-        if not name:
-            name = self.name
-        reader = Read.get_reader(name)
-        if not prefix:
-            prefix = name
-        reader.prefix = prefix
-        return reader
+    def initialise_values_sources(self) -> None:
+        """
+        Create values and sources member variables for inheriting scrapers to populate.
+        values will be of form:
+        {"national": ({"AFG": 1.2, "PSE": 1.4}, {"AFG": 123, "PSE": 241}, ...})}
+        sources will be of form:
+        {"national": [("#food-prices", "2022-07-15", "WFP", "https://data.humdata.org/dataset/global-wfp-food-prices"), ...]
 
-    def initialise_values_sources(self):
+        Returns:
+             None
+        """
         self.values: Dict[str, Tuple] = {
             level: tuple(dict() for _ in value[0])
             for level, value in self.headers.items()
@@ -57,12 +61,34 @@ class BaseScraper(ABC):
             level: list() for level in self.headers
         }
 
-    def get_headers(self, level: str) -> Optional[Tuple[Tuple]]:
-        """
-        Get headers for a particular level_name like national or subnational
+    def get_reader(
+        self, name: Optional[str] = None, prefix: Optional[str] = None
+    ):
+        """Get reader given name if provided or using name member variable if not.
+        Set reader prefix to given prefix or name if not provided.
 
         Args:
-            level (str): Level for which to get headers
+            name (str): Name of scraper
+            prefix (Optional[str]): Prefix to use. Defaults to None (use scraper name).
+
+        Returns:
+             None
+        """
+        if not name:
+            name = self.name
+        reader = Read.get_reader(name)
+        if not prefix:
+            prefix = name
+        reader.prefix = prefix
+        return reader
+
+    def get_headers(self, level: str) -> Optional[Tuple[Tuple]]:
+        """
+        Get headers for a particular level_name like national or subnational. Will be
+        of form: (("School Closure",), ("#impact+type",))
+
+        Args:
+            level (str): Level to get like national, subnational or single
 
         Returns:
             Optional[Tuple[Tuple]]: Scraper headers or None
@@ -71,7 +97,8 @@ class BaseScraper(ABC):
 
     def get_values(self, level: str) -> Optional[Tuple]:
         """
-        Get values for a particular level_name like national or subnational
+        Get values for a particular level_name like national or subnational. Will be of
+        form: ({"AFG": 1.2, "PSE": 1.4}, {"AFG": 123, "PSE": 241}, ...})}
 
         Args:
             level (str): Level for which to get headers
@@ -81,12 +108,12 @@ class BaseScraper(ABC):
         """
         return self.values.get(level)
 
-    def add_sources(self):
+    def add_sources(self) -> None:
         """
         Adds sources for a particular level_name
 
         Returns:
-            List[Tuple]: List of (hxltag, date, source, source url)
+            None
 
         """
         source = self.datasetinfo["source"]
@@ -109,20 +136,48 @@ class BaseScraper(ABC):
                 for hxltag in self.headers[level][1]
             ]
 
-    def add_hxltag_source(self, tab: str, hxltag: str) -> None:
-        self.sources[tab] = [
+    def add_hxltag_source(self, key: str, indicator: str) -> None:
+        """
+        Adds source under a particular key with a particular indicator expressed as a
+        HXL hashtag.
+
+        Args:
+            key (str): Key under which to add source
+            indicator (str): HXL hashtag to use for source
+
+        Returns:
+            None
+        """
+        self.sources[key] = [
             (
-                hxltag,
+                indicator,
                 self.datasetinfo["source_date"].strftime("%Y-%m-%d"),
                 self.datasetinfo["source"],
                 self.datasetinfo["source_url"],
             )
         ]
 
-    def get_sources(self, level):
+    def get_sources(self, level: str) -> Optional[List[Tuple]]:
+        """
+        Get values for a particular level_name like national or subnational. Will be of
+        form:
+        [("#food-prices", "2022-07-15", "WFP", "https://data.humdata.org/dataset/global-wfp-food-prices"), ...]
+
+        Args:
+            level (str): Level to get like national, subnational or single
+
+        Returns:
+            Optional[List[Tuple]]: Scraper sources or None
+        """
         return self.sources.get(level)
 
     def add_source_urls(self) -> None:
+        """
+        Add source urls from the datasetinfo member variable
+
+        Returns:
+            None
+        """
         source_url = self.datasetinfo.get("source_url")
         if source_url:
             if isinstance(source_url, str):
@@ -131,10 +186,23 @@ class BaseScraper(ABC):
                 for url in source_url.values():
                     self.source_urls.add(url)
 
-    def get_source_urls(self):
+    def get_source_urls(self) -> Set[str]:
+        """
+        Get source urls
+
+        Returns:
+            Set[str]: Source urls
+        """
         return self.source_urls
 
-    def add_population(self):
+    def add_population(self) -> None:
+        """
+        Add population data by looking for the #population HXL hashtag among the
+        headers and pulling out the associated values
+
+        Returns:
+            None
+        """
         for level in self.headers:
             try:
                 population_index = self.headers[level][1].index("#population")
@@ -151,7 +219,7 @@ class BaseScraper(ABC):
     @abstractmethod
     def run(self) -> None:
         """
-        Run scraper
+        Run scraper. Must be overridden.
 
         Returns:
             None
@@ -159,7 +227,7 @@ class BaseScraper(ABC):
 
     def run_after_fallbacks(self) -> None:
         """
-        Executed after fallbacks are used
+        Executed after fallbacks are used. Can be overridden if needed.
 
         Returns:
             None
@@ -168,7 +236,7 @@ class BaseScraper(ABC):
 
     def post_run(self) -> None:
         """
-        Executed after running
+        Executed after running. Can be overridden if needed.
 
         Returns:
             None
